@@ -5,11 +5,11 @@ import (
 	"fmt"
 	"os"
 	"reflect"
-	"sort"
+	"slices"
 	"strings"
 )
 
-// nolint: gochecknoglobals
+//nolint:gochecknoglobals
 var (
 	MockEnvVar = "GORELEASER_MOCK_DATA"
 	MockCmd    = os.Args[0]
@@ -39,7 +39,7 @@ func (m *MockData) UnmarshalJSON(b []byte) error {
 
 // MarshalMockEnv mocks marshal.
 //
-// nolint: interfacer
+//nolint:interfacer
 func MarshalMockEnv(data *MockData) string {
 	b, err := data.MarshalJSON()
 	if err != nil {
@@ -82,10 +82,10 @@ func ExecuteMockData(jsonData string) int {
 			item.ExpectedEnv = []string{}
 		}
 
-		sort.Strings(givenEnv)
-		sort.Strings(item.ExpectedEnv)
-		sort.Strings(givenArgs)
-		sort.Strings(item.ExpectedArgs)
+		slices.Sort(givenEnv)
+		slices.Sort(item.ExpectedEnv)
+		slices.Sort(givenArgs)
+		slices.Sort(item.ExpectedArgs)
 
 		if reflect.DeepEqual(item.ExpectedArgs, givenArgs) &&
 			reflect.DeepEqual(item.ExpectedEnv, givenEnv) {
