@@ -7,15 +7,18 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"net/http"
 	h "net/http"
 	"net/http/httptest"
 	"os"
 	"path/filepath"
 	"strings"
 	"sync"
+	"sync/atomic"
 	"testing"
 
 	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe"
 	"github.com/goreleaser/goreleaser/v2/internal/testctx"
 	"github.com/goreleaser/goreleaser/v2/pkg/config"
 	"github.com/goreleaser/goreleaser/v2/pkg/context"
@@ -701,3 +704,48 @@ func cert(srv *httptest.Server) string {
 	}
 	return string(pem.EncodeToMemory(block))
 }
+
+func TestManyUploads(t *testing.T) {
+	var uploaded atomic.Bool
+	srv := httptest.NewServer(http.HandlerFunc(func(w h.ResponseWriter, _ *h.Request) {
+		w.WriteHeader(h.StatusCreated)
+		uploaded.Store(true)
+	}))
+	t.Cleanup(srv.Close)
+	assetOpen = func(string, *artifact.Artifact) (*asset, error) {
+		return &asset{
+			ReadCloser: io.NopCloser(strings.NewReader("a")),
+			Size:       1,
+		}, nil
+	}
+	defer assetOpenReset()
+	ctx := testctx.NewWithCfg(config.Project{
+		ProjectName: "blah",
+		Env:         []string{"FOO=1"},
+		Uploads: []config.Upload{
+			{
+				Name: "skip1",
+				Skip: "true",
+			},
+			{
+				Name:     "real",
+				Mode:     "archive",
+				Checksum: true,
+				Target:   srv.URL,
+			},
+			{
+				Name: "skip1",
+				Skip: `{{ eq .Env.FOO "1" }}`,
+			},
+		},
+	}, testctx.WithVersion("2.1.0"))
+	ctx.Artifacts.Add(&artifact.Artifact{
+		Name: "checksums.txt",
+		Path: "doesnt-matter",
+		Type: artifact.Checksum,
+	})
+	err := Upload(ctx, ctx.Config.Uploads, "test", func(*h.Response) error { return nil })
+	require.Error(t, err)
+	require.True(t, pipe.IsSkip(err), err)
+	require.True(t, uploaded.Load(), "should have uploaded")
+}
