@@ -9,12 +9,14 @@ import (
 	"io/fs"
 	"os"
 	"path/filepath"
+	"slices"
 	"strings"
 	"sync"
 
 	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/v2/internal/archivefiles"
 	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/deprecate"
 	"github.com/goreleaser/goreleaser/v2/internal/ids"
 	"github.com/goreleaser/goreleaser/v2/internal/semerrgroup"
 	"github.com/goreleaser/goreleaser/v2/internal/skips"
@@ -33,7 +35,7 @@ const (
 // ErrArchiveDifferentBinaryCount happens when an archive uses several builds which have different goos/goarch/etc sets,
 // causing the archives for some platforms to have more binaries than others.
 // GoReleaser breaks in these cases as it will only cause confusion to other users.
-var ErrArchiveDifferentBinaryCount = errors.New("archive has different count of binaries for each platform, which may cause your users confusion.\nLearn more at https://goreleaser.com/errors/multiple-binaries-archive\n") //nolint:revive
+var ErrArchiveDifferentBinaryCount = errors.New("archive has different count of binaries for each platform, which may cause your users confusion.\nLearn more at https://goreleaser.com/errors/multiple-binaries-archive")
 
 //nolint:gochecknoglobals
 var lock sync.Mutex
@@ -57,8 +59,19 @@ func (Pipe) Default(ctx *context.Context) error {
 	}
 	for i := range ctx.Config.Archives {
 		archive := &ctx.Config.Archives[i]
-		if archive.Format == "" {
-			archive.Format = "tar.gz"
+		if archive.Format != "" {
+			deprecate.Notice(ctx, "archives.format")
+			archive.Formats = append(archive.Formats, archive.Format)
+		}
+		if len(archive.Formats) == 0 {
+			archive.Formats = []string{"tar.gz"}
+		}
+		for i := range archive.FormatOverrides {
+			over := &archive.FormatOverrides[i]
+			if over.Format != "" {
+				deprecate.Notice(ctx, "archives.format_overrides.format")
+				over.Formats = append(over.Formats, over.Format)
+			}
 		}
 		if archive.ID == "" {
 			archive.ID = "default"
@@ -75,7 +88,7 @@ func (Pipe) Default(ctx *context.Context) error {
 		}
 		if archive.NameTemplate == "" {
 			archive.NameTemplate = defaultNameTemplate
-			if archive.Format == "binary" {
+			if slices.Contains(archive.Formats, "binary") {
 				archive.NameTemplate = defaultBinaryNameTemplate
 			}
 		}
@@ -89,9 +102,11 @@ func (Pipe) Run(ctx *context.Context) error {
 	g := semerrgroup.New(ctx.Parallelism)
 	for i, archive := range ctx.Config.Archives {
 		if archive.Meta {
-			g.Go(func() error {
-				return createMeta(ctx, archive)
-			})
+			for _, format := range archive.Formats {
+				g.Go(func() error {
+					return createMeta(ctx, archive, format)
+				})
+			}
 			continue
 		}
 
@@ -105,25 +120,29 @@ func (Pipe) Run(ctx *context.Context) error {
 		if len(archive.Builds) > 0 {
 			filter = append(filter, artifact.ByIDs(archive.Builds...))
 		}
+
+		isBinary := slices.Contains(archive.Formats, "binary")
 		artifacts := ctx.Artifacts.Filter(artifact.And(filter...)).GroupByPlatform()
-		if err := checkArtifacts(artifacts); err != nil && archive.Format != "binary" && !archive.AllowDifferentBinaryCount {
+		if err := checkArtifacts(artifacts); err != nil && !isBinary && !archive.AllowDifferentBinaryCount {
 			return fmt.Errorf("invalid archive: %d: %w", i, ErrArchiveDifferentBinaryCount)
 		}
 		for group, artifacts := range artifacts {
 			log.Debugf("group %s has %d binaries", group, len(artifacts))
-			format := packageFormat(archive, artifacts[0].Goos)
-			switch format {
-			case "none":
-				// do nothing
-				log.WithField("goos", artifacts[0].Goos).Info("ignored due to format override to 'none'")
-			case "binary":
-				g.Go(func() error {
-					return skip(ctx, archive, artifacts)
-				})
-			default:
-				g.Go(func() error {
-					return create(ctx, archive, artifacts, format)
-				})
+			formats := packageFormats(archive, artifacts[0].Goos)
+			for _, format := range formats {
+				switch format {
+				case "none":
+					// do nothing
+					log.WithField("goos", artifacts[0].Goos).Info("ignored due to format override to 'none'")
+				case "binary":
+					g.Go(func() error {
+						return skip(ctx, archive, artifacts)
+					})
+				default:
+					g.Go(func() error {
+						return create(ctx, archive, artifacts, format)
+					})
+				}
 			}
 		}
 	}
@@ -141,8 +160,8 @@ func checkArtifacts(artifacts map[string][]*artifact.Artifact) error {
 	return ErrArchiveDifferentBinaryCount
 }
 
-func createMeta(ctx *context.Context, arch config.Archive) error {
-	return create(ctx, arch, nil, arch.Format)
+func createMeta(ctx *context.Context, arch config.Archive, format string) error {
+	return create(ctx, arch, nil, format)
 }
 
 func create(ctx *context.Context, arch config.Archive, binaries []*artifact.Artifact, format string) error {
@@ -288,13 +307,13 @@ func skip(ctx *context.Context, archive config.Archive, binaries []*artifact.Art
 	return nil
 }
 
-func packageFormat(archive config.Archive, platform string) string {
+func packageFormats(archive config.Archive, platform string) []string {
 	for _, override := range archive.FormatOverrides {
 		if strings.HasPrefix(platform, override.Goos) {
-			return override.Format
+			return override.Formats
 		}
 	}
-	return archive.Format
+	return archive.Formats
 }
 
 // NewEnhancedArchive enhances a pre-existing archive.Archive instance
