@@ -8,6 +8,7 @@ import (
 	"io/fs"
 	"os"
 	"path/filepath"
+	"strings"
 	"testing"
 
 	"github.com/goreleaser/goreleaser/v2/internal/artifact"
@@ -35,29 +36,20 @@ func createFakeBinary(t *testing.T, dist, arch, bin string) {
 func TestRunPipe(t *testing.T) {
 	folder := testlib.Mktmp(t)
 	for _, dets := range []struct {
-		Format string
-		Strip  bool
+		Formats []string
+		Strip   bool
 	}{
 		{
-			Format: "tar.gz",
-			Strip:  true,
+			Formats: []string{"tar.gz", "zip"},
+			Strip:   true,
 		},
 		{
-			Format: "tar.gz",
-			Strip:  false,
-		},
-
-		{
-			Format: "zip",
-			Strip:  true,
-		},
-		{
-			Format: "zip",
-			Strip:  false,
+			Formats: []string{"tar.gz", "zip"},
+			Strip:   false,
 		},
 	} {
-		format := dets.Format
-		name := "archive." + format
+		formats := dets.Formats
+		name := "archive." + strings.Join(formats, ",")
 		if dets.Strip {
 			name = "strip_" + name
 		}
@@ -89,6 +81,7 @@ func TestRunPipe(t *testing.T) {
 								Owner: "root",
 								Group: "root",
 							},
+							Formats:              formats,
 							NameTemplate:         defaultNameTemplate,
 							StripBinaryDirectory: dets.Strip,
 							Files: []config.File{
@@ -97,12 +90,12 @@ func TestRunPipe(t *testing.T) {
 							},
 							FormatOverrides: []config.FormatOverride{
 								{
-									Goos:   "windows",
-									Format: "zip",
+									Goos:    "windows",
+									Formats: []string{"zip"},
 								},
 								{
-									Goos:   "freebsd",
-									Format: "none",
+									Goos:    "freebsd",
+									Formats: []string{"none"},
 								},
 							},
 						},
@@ -215,7 +208,6 @@ func TestRunPipe(t *testing.T) {
 			ctx.Artifacts.Add(freebsdAmd64Build)
 			ctx.Version = "0.0.1"
 			ctx.Git.CurrentTag = "v0.0.1"
-			ctx.Config.Archives[0].Format = format
 			require.NoError(t, Pipe{}.Run(ctx))
 
 			require.Empty(t, ctx.Artifacts.Filter(
@@ -238,7 +230,7 @@ func TestRunPipe(t *testing.T) {
 				require.Equal(t, []string{expectBin}, artifact.ExtraOr(*arch, artifact.ExtraBinaries, []string{}))
 				require.Equal(t, "", artifact.ExtraOr(*arch, artifact.ExtraBinary, ""))
 			}
-			require.Len(t, archives, 7)
+			require.Len(t, archives, 13)
 			// TODO: should verify the artifact fields here too
 
 			expectBin := "bin/mybin"
@@ -246,42 +238,38 @@ func TestRunPipe(t *testing.T) {
 				expectBin = "mybin"
 			}
 
-			if format == "tar.gz" {
-				// Check archive contents
-				for name, os := range map[string]string{
-					"foobar_0.0.1_darwin_amd64.tar.gz":         "darwin",
-					"foobar_0.0.1_darwin_all.tar.gz":           "darwin",
-					"foobar_0.0.1_linux_386.tar.gz":            "linux",
-					"foobar_0.0.1_linux_armv7.tar.gz":          "linux",
-					"foobar_0.0.1_linux_mips_softfloat.tar.gz": "linux",
-					"foobar_0.0.1_linux_amd64v3.tar.gz":        "linux",
-				} {
-					require.Equal(
-						t,
-						[]string{
-							fmt.Sprintf("README.%s.md", os),
-							"foo/bar/foobar/blah.txt",
-							expectBin,
-						},
-						testlib.LsArchive(t, filepath.Join(dist, name), "tar.gz"),
-					)
-
-					header := tarInfo(t, filepath.Join(dist, name), expectBin)
-					require.Equal(t, "root", header.Uname)
-					require.Equal(t, "root", header.Gname)
-				}
-			}
-			if format == "zip" {
+			// Check archive contents
+			for name, os := range map[string]string{
+				"foobar_0.0.1_darwin_amd64.tar.gz":         "darwin",
+				"foobar_0.0.1_darwin_all.tar.gz":           "darwin",
+				"foobar_0.0.1_linux_386.tar.gz":            "linux",
+				"foobar_0.0.1_linux_armv7.tar.gz":          "linux",
+				"foobar_0.0.1_linux_mips_softfloat.tar.gz": "linux",
+				"foobar_0.0.1_linux_amd64v3.tar.gz":        "linux",
+			} {
 				require.Equal(
 					t,
 					[]string{
-						"README.windows.md",
+						fmt.Sprintf("README.%s.md", os),
 						"foo/bar/foobar/blah.txt",
-						expectBin + ".exe",
+						expectBin,
 					},
-					testlib.LsArchive(t, filepath.Join(dist, "foobar_0.0.1_windows_amd64.zip"), "zip"),
+					testlib.LsArchive(t, filepath.Join(dist, name), "tar.gz"),
 				)
+
+				header := tarInfo(t, filepath.Join(dist, name), expectBin)
+				require.Equal(t, "root", header.Uname)
+				require.Equal(t, "root", header.Gname)
 			}
+			require.Equal(
+				t,
+				[]string{
+					"README.windows.md",
+					"foo/bar/foobar/blah.txt",
+					expectBin + ".exe",
+				},
+				testlib.LsArchive(t, filepath.Join(dist, "foobar_0.0.1_windows_amd64.zip"), "zip"),
+			)
 		})
 	}
 }
@@ -300,7 +288,7 @@ func TestRunPipeDifferentBinaryCount(t *testing.T) {
 		Archives: []config.Archive{
 			{
 				ID:           "myid",
-				Format:       "tar.gz",
+				Formats:      []string{"tar.gz"},
 				Builds:       []string{"default", "foobar"},
 				NameTemplate: defaultNameTemplate,
 			},
@@ -426,7 +414,7 @@ func TestRunPipeBinary(t *testing.T) {
 			Dist: dist,
 			Archives: []config.Archive{
 				{
-					Format:       "binary",
+					Formats:      []string{"binary"},
 					NameTemplate: defaultBinaryNameTemplate,
 					Builds:       []string{"default", "default2"},
 				},
@@ -514,7 +502,7 @@ func TestRunPipeDistRemoved(t *testing.T) {
 			Archives: []config.Archive{
 				{
 					NameTemplate: "nope",
-					Format:       "zip",
+					Formats:      []string{"zip"},
 					Builds:       []string{"default"},
 				},
 			},
@@ -552,7 +540,7 @@ func TestRunPipeInvalidGlob(t *testing.T) {
 				{
 					Builds:       []string{"default"},
 					NameTemplate: "foo",
-					Format:       "zip",
+					Formats:      []string{"zip"},
 					Files: []config.File{
 						{Source: "[x-]"},
 					},
@@ -591,12 +579,12 @@ func TestRunPipeNameTemplateWithSpace(t *testing.T) {
 				{
 					Builds:       []string{"default"},
 					NameTemplate: " foo_{{.Os}}_{{.Arch}} ",
-					Format:       "zip",
+					Formats:      []string{"zip"},
 				},
 				{
 					Builds:       []string{"default"},
 					NameTemplate: " foo_{{.Os}}_{{.Arch}} ",
-					Format:       "binary",
+					Formats:      []string{"binary"},
 				},
 			},
 		},
@@ -637,7 +625,7 @@ func TestRunPipeInvalidNameTemplate(t *testing.T) {
 				{
 					Builds:       []string{"default"},
 					NameTemplate: "foo{{ .fff }",
-					Format:       "zip",
+					Formats:      []string{"zip"},
 				},
 			},
 		},
@@ -672,7 +660,7 @@ func TestRunPipeInvalidFilesNameTemplate(t *testing.T) {
 				{
 					Builds:       []string{"default"},
 					NameTemplate: "foo",
-					Format:       "zip",
+					Formats:      []string{"zip"},
 					Files: []config.File{
 						{Source: "{{.asdsd}"},
 					},
@@ -711,7 +699,7 @@ func TestRunPipeInvalidWrapInDirectoryTemplate(t *testing.T) {
 					Builds:          []string{"default"},
 					NameTemplate:    "foo",
 					WrapInDirectory: "foo{{ .fff }",
-					Format:          "zip",
+					Formats:         []string{"zip"},
 				},
 			},
 		},
@@ -750,7 +738,7 @@ func TestRunPipeWrap(t *testing.T) {
 					Builds:          []string{"default"},
 					NameTemplate:    "foo",
 					WrapInDirectory: "foo_{{ .Os }}",
-					Format:          "tar.gz",
+					Formats:         []string{"tar.gz"},
 					Files: []config.File{
 						{Source: "README.*"},
 					},
@@ -789,7 +777,7 @@ func TestDefault(t *testing.T) {
 	})
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.NotEmpty(t, ctx.Config.Archives[0].NameTemplate)
-	require.Equal(t, "tar.gz", ctx.Config.Archives[0].Format)
+	require.Equal(t, "tar.gz", ctx.Config.Archives[0].Formats[0])
 	require.NotEmpty(t, ctx.Config.Archives[0].Files)
 }
 
@@ -799,7 +787,7 @@ func TestDefaultSet(t *testing.T) {
 			{
 				Builds:       []string{"default"},
 				NameTemplate: "foo",
-				Format:       "zip",
+				Formats:      []string{"zip"},
 				Files: []config.File{
 					{Source: "foo"},
 				},
@@ -808,15 +796,27 @@ func TestDefaultSet(t *testing.T) {
 	})
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.Equal(t, "foo", ctx.Config.Archives[0].NameTemplate)
-	require.Equal(t, "zip", ctx.Config.Archives[0].Format)
+	require.Equal(t, "zip", ctx.Config.Archives[0].Formats[0])
 	require.Equal(t, config.File{Source: "foo"}, ctx.Config.Archives[0].Files[0])
 }
 
+func TestDefaultMixFormats(t *testing.T) {
+	ctx := testctx.NewWithCfg(config.Project{
+		Archives: []config.Archive{
+			{
+				Formats: []string{"tar.gz", "binary"},
+			},
+		},
+	})
+	require.NoError(t, Pipe{}.Default(ctx))
+	require.Equal(t, defaultBinaryNameTemplate, ctx.Config.Archives[0].NameTemplate)
+}
+
 func TestDefaultNoFiles(t *testing.T) {
 	ctx := testctx.NewWithCfg(config.Project{
 		Archives: []config.Archive{
 			{
-				Format: "tar.gz",
+				Formats: []string{"tar.gz"},
 			},
 		},
 	})
@@ -828,7 +828,7 @@ func TestDefaultFormatBinary(t *testing.T) {
 	ctx := testctx.NewWithCfg(config.Project{
 		Archives: []config.Archive{
 			{
-				Format: "binary",
+				Formats: []string{"binary"},
 			},
 		},
 	})
@@ -840,24 +840,24 @@ func TestFormatFor(t *testing.T) {
 	ctx := testctx.NewWithCfg(config.Project{
 		Archives: []config.Archive{
 			{
-				Builds: []string{"default"},
-				Format: "tar.gz",
+				Builds:  []string{"default"},
+				Formats: []string{"tar.gz", "tar.xz"},
 				FormatOverrides: []config.FormatOverride{
 					{
-						Goos:   "windows",
-						Format: "zip",
+						Goos:    "windows",
+						Formats: []string{"zip", "7z"},
 					},
 					{
-						Goos:   "darwin",
-						Format: "none",
+						Goos:    "darwin",
+						Formats: []string{"none"},
 					},
 				},
 			},
 		},
 	})
-	require.Equal(t, "zip", packageFormat(ctx.Config.Archives[0], "windows"))
-	require.Equal(t, "tar.gz", packageFormat(ctx.Config.Archives[0], "linux"))
-	require.Equal(t, "none", packageFormat(ctx.Config.Archives[0], "darwin"))
+	require.Equal(t, []string{"zip", "7z"}, packageFormats(ctx.Config.Archives[0], "windows"))
+	require.Equal(t, []string{"tar.gz", "tar.xz"}, packageFormats(ctx.Config.Archives[0], "linux"))
+	require.Equal(t, []string{"none"}, packageFormats(ctx.Config.Archives[0], "darwin"))
 }
 
 func TestBinaryOverride(t *testing.T) {
@@ -875,70 +875,71 @@ func TestBinaryOverride(t *testing.T) {
 	f, err = os.Create(filepath.Join(folder, "README.md"))
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	for _, format := range []string{"tar.gz", "zip"} {
-		t.Run("Archive format "+format, func(t *testing.T) {
-			ctx := testctx.NewWithCfg(
-				config.Project{
-					Dist:        dist,
-					ProjectName: "foobar",
-					Archives: []config.Archive{
+	ctx := testctx.NewWithCfg(
+		config.Project{
+			Dist:        dist,
+			ProjectName: "foobar",
+			Archives: []config.Archive{
+				{
+					Builds:       []string{"default"},
+					NameTemplate: defaultNameTemplate,
+					Files: []config.File{
+						{Source: "README.*"},
+					},
+					Formats: []string{"tar.gz", "zip"},
+					FormatOverrides: []config.FormatOverride{
 						{
-							Builds:       []string{"default"},
-							NameTemplate: defaultNameTemplate,
-							Files: []config.File{
-								{Source: "README.*"},
-							},
-							FormatOverrides: []config.FormatOverride{
-								{
-									Goos:   "windows",
-									Format: "binary",
-								},
-							},
+							Goos:    "windows",
+							Formats: []string{"binary"},
 						},
 					},
 				},
-				testctx.WithCurrentTag("v0.0.1"),
-			)
-			ctx.Artifacts.Add(&artifact.Artifact{
-				Goos:   "darwin",
-				Goarch: "amd64",
-				Name:   "mybin",
-				Path:   filepath.Join(dist, "darwinamd64", "mybin"),
-				Type:   artifact.Binary,
-				Extra: map[string]interface{}{
-					artifact.ExtraBinary: "mybin",
-					artifact.ExtraID:     "default",
-				},
-			})
-			ctx.Artifacts.Add(&artifact.Artifact{
-				Goos:   "windows",
-				Goarch: "amd64",
-				Name:   "mybin.exe",
-				Path:   filepath.Join(dist, "windowsamd64", "mybin.exe"),
-				Type:   artifact.Binary,
-				Extra: map[string]interface{}{
-					artifact.ExtraBinary: "mybin",
-					artifact.ExtraExt:    ".exe",
-					artifact.ExtraID:     "default",
-				},
-			})
-			ctx.Version = "0.0.1"
-			ctx.Config.Archives[0].Format = format
+			},
+		},
+		testctx.WithCurrentTag("v0.0.1"),
+	)
+	ctx.Artifacts.Add(&artifact.Artifact{
+		Goos:   "darwin",
+		Goarch: "amd64",
+		Name:   "mybin",
+		Path:   filepath.Join(dist, "darwinamd64", "mybin"),
+		Type:   artifact.Binary,
+		Extra: map[string]interface{}{
+			artifact.ExtraBinary: "mybin",
+			artifact.ExtraID:     "default",
+		},
+	})
+	ctx.Artifacts.Add(&artifact.Artifact{
+		Goos:   "windows",
+		Goarch: "amd64",
+		Name:   "mybin.exe",
+		Path:   filepath.Join(dist, "windowsamd64", "mybin.exe"),
+		Type:   artifact.Binary,
+		Extra: map[string]interface{}{
+			artifact.ExtraBinary: "mybin",
+			artifact.ExtraExt:    ".exe",
+			artifact.ExtraID:     "default",
+		},
+	})
+	ctx.Version = "0.0.1"
 
-			require.NoError(t, Pipe{}.Run(ctx))
-			archives := ctx.Artifacts.Filter(artifact.ByType(artifact.UploadableArchive))
-			darwin := archives.Filter(artifact.ByGoos("darwin")).List()[0]
-			require.Equal(t, "foobar_0.0.1_darwin_amd64."+format, darwin.Name)
-			require.Equal(t, format, darwin.Format())
-			require.Empty(t, artifact.ExtraOr(*darwin, artifact.ExtraWrappedIn, ""))
+	require.NoError(t, Pipe{}.Run(ctx))
+	archives := ctx.Artifacts.Filter(artifact.ByType(artifact.UploadableArchive))
 
-			archives = ctx.Artifacts.Filter(artifact.ByType(artifact.UploadableBinary))
-			windows := archives.Filter(artifact.ByGoos("windows")).List()[0]
-			require.Equal(t, "foobar_0.0.1_windows_amd64.exe", windows.Name)
-			require.Empty(t, artifact.ExtraOr(*windows, artifact.ExtraWrappedIn, ""))
-			require.Equal(t, "mybin.exe", artifact.ExtraOr(*windows, artifact.ExtraBinary, ""))
-		})
+	darwins := archives.Filter(artifact.ByGoos("darwin")).List()
+	require.Len(t, darwins, 2)
+	for _, darwin := range darwins {
+		format := darwin.Format()
+		require.Contains(t, []string{"tar.gz", "zip"}, format)
+		require.Equal(t, "foobar_0.0.1_darwin_amd64."+format, darwin.Name)
+		require.Empty(t, artifact.ExtraOr(*darwin, artifact.ExtraWrappedIn, ""))
 	}
+
+	archives = ctx.Artifacts.Filter(artifact.ByType(artifact.UploadableBinary))
+	windows := archives.Filter(artifact.ByGoos("windows")).List()[0]
+	require.Equal(t, "foobar_0.0.1_windows_amd64.exe", windows.Name)
+	require.Empty(t, artifact.ExtraOr(*windows, artifact.ExtraWrappedIn, ""))
+	require.Equal(t, "mybin.exe", artifact.ExtraOr(*windows, artifact.ExtraBinary, ""))
 }
 
 func TestRunPipeSameArchiveFilename(t *testing.T) {
@@ -965,7 +966,7 @@ func TestRunPipeSameArchiveFilename(t *testing.T) {
 						{Source: "README.*"},
 						{Source: "./foo/**/*"},
 					},
-					Format: "tar.gz",
+					Formats: []string{"tar.gz"},
 				},
 			},
 		},
@@ -1071,7 +1072,7 @@ func TestArchive_globbing(t *testing.T) {
 			Archives: []config.Archive{
 				{
 					Builds:       []string{"default"},
-					Format:       "tar.gz",
+					Formats:      []string{"tar.gz"},
 					NameTemplate: "foo",
 					Files:        files,
 				},
@@ -1151,7 +1152,7 @@ func TestInvalidFormat(t *testing.T) {
 				ID:           "foo",
 				NameTemplate: "foo",
 				Meta:         true,
-				Format:       "7z",
+				Formats:      []string{"7z"},
 			},
 		},
 	})
@@ -1166,7 +1167,7 @@ func TestIssue3803(t *testing.T) {
 				ID:           "foo",
 				NameTemplate: "foo",
 				Meta:         true,
-				Format:       "zip",
+				Formats:      []string{"zip"},
 				Files: []config.File{
 					{Source: "./testdata/a/a.txt"},
 				},
@@ -1175,7 +1176,7 @@ func TestIssue3803(t *testing.T) {
 				ID:           "foobar",
 				NameTemplate: "foobar",
 				Meta:         true,
-				Format:       "zip",
+				Formats:      []string{"zip"},
 				Files: []config.File{
 					{Source: "./testdata/a/b/a.txt"},
 				},
@@ -1194,10 +1195,10 @@ func TestExtraFormatWhenOverride(t *testing.T) {
 			{
 				ID:           "foo",
 				NameTemplate: "foo",
-				Format:       "tar.gz",
+				Formats:      []string{"tar.gz"},
 				FormatOverrides: []config.FormatOverride{{
-					Goos:   "windows",
-					Format: "zip",
+					Goos:    "windows",
+					Formats: []string{"zip"},
 				}},
 				Files: []config.File{
 					{Source: "./testdata/a/a.txt"},
@@ -1237,3 +1238,22 @@ func TestSkip(t *testing.T) {
 		require.False(t, Pipe{}.Skip(testctx.New()))
 	})
 }
+
+func TestDefaultDeprecatd(t *testing.T) {
+	ctx := testctx.NewWithCfg(config.Project{
+		Archives: []config.Archive{
+			{
+				Format: "tar.gz",
+				FormatOverrides: []config.FormatOverride{
+					{
+						Format: "zip",
+					},
+				},
+			},
+		},
+	})
+	require.NoError(t, Pipe{}.Default(ctx))
+	require.True(t, ctx.Deprecated)
+	require.Equal(t, "tar.gz", ctx.Config.Archives[0].Formats[0])
+	require.Equal(t, "zip", ctx.Config.Archives[0].FormatOverrides[0].Formats[0])
+}
