@@ -3,9 +3,11 @@ package docker
 import (
 	"fmt"
 	"maps"
+	"math"
 	"slices"
 	"strings"
 
+	"github.com/agnivade/levenshtein"
 	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/v2/internal/artifact"
 	"github.com/goreleaser/goreleaser/v2/internal/ids"
@@ -139,7 +141,7 @@ func manifestImages(ctx *context.Context, manifest config.DockerManifest) ([]str
 		if err != nil {
 			return []string{}, err
 		}
-		imgs = append(imgs, withDigest(manifest.Use, str, artifacts))
+		imgs = append(imgs, withDigest(str, artifacts))
 	}
 	if strings.TrimSpace(strings.Join(manifest.ImageTemplates, "")) == "" {
 		return imgs, pipe.Skip("manifest has no images")
@@ -147,15 +149,26 @@ func manifestImages(ctx *context.Context, manifest config.DockerManifest) ([]str
 	return imgs, nil
 }
 
-func withDigest(use, name string, images []*artifact.Artifact) string {
+func withDigest(name string, images []*artifact.Artifact) string {
 	for _, art := range images {
 		if art.Name == name {
 			if digest := artifact.ExtraOr(*art, artifact.ExtraDigest, ""); digest != "" {
 				return name + "@" + digest
 			}
-			break
+			log.Warnf("unknown digest for %q, using insecure mode", name)
+			return name
 		}
 	}
-	log.Warnf("did not find the digest for %s using %s, defaulting to insecure mode", name, use)
+
+	suggestion := ""
+	suggestionDistance := math.MaxInt
+	for _, img := range images {
+		if d := levenshtein.ComputeDistance(name, img.Name); d < suggestionDistance {
+			suggestion = name
+			suggestionDistance = d
+		}
+	}
+
+	log.Warnf("culd not find %q, did you mean %q?", name, suggestion)
 	return name
 }
