@@ -7,6 +7,7 @@ import (
 	"os"
 	"path/filepath"
 	"strings"
+	"time"
 
 	"dario.cat/mergo"
 	"github.com/caarlos0/log"
@@ -265,6 +266,7 @@ func create(ctx *context.Context, fpm config.NFPM, format string, artifacts []*a
 		&fpm.Homepage,
 		&fpm.Description,
 		&fpm.Maintainer,
+		&fpm.MTime,
 		&overridden.Scripts.PostInstall,
 		&overridden.Scripts.PreInstall,
 		&overridden.Scripts.PostRemove,
@@ -273,6 +275,14 @@ func create(ctx *context.Context, fpm config.NFPM, format string, artifacts []*a
 		return err
 	}
 
+	if fpm.MTime != "" {
+		var err error
+		fpm.ParsedMTime, err = time.Parse(time.RFC3339Nano, fpm.MTime)
+		if err != nil {
+			return fmt.Errorf("failed to parse %s: %w", fpm.MTime, err)
+		}
+	}
+
 	// We cannot use t.ApplyAll on the following fields as they are shared
 	// across multiple nfpms.
 	//
@@ -317,20 +327,33 @@ func create(ctx *context.Context, fpm config.NFPM, format string, artifacts []*a
 
 	contents := files.Contents{}
 	for _, content := range overridden.Contents {
-		src, err := t.Apply(content.Source)
-		if err != nil {
+		if err := t.ApplyAll(
+			&content.Source,
+			&content.Destination,
+			&content.FileInfo.Owner,
+			&content.FileInfo.Group,
+			&content.FileInfo.MTime,
+		); err != nil {
 			return err
 		}
-		dst, err := t.Apply(content.Destination)
-		if err != nil {
-			return err
+		if content.FileInfo.MTime != "" {
+			var err error
+			content.FileInfo.ParsedMTime, err = time.Parse(time.RFC3339Nano, content.FileInfo.MTime)
+			if err != nil {
+				return fmt.Errorf("failed to parse %s: %w", fpm.MTime, err)
+			}
 		}
 		contents = append(contents, &files.Content{
-			Source:      filepath.ToSlash(src),
-			Destination: filepath.ToSlash(dst),
+			Source:      filepath.ToSlash(content.Source),
+			Destination: filepath.ToSlash(content.Destination),
 			Type:        content.Type,
 			Packager:    content.Packager,
-			FileInfo:    content.FileInfo,
+			FileInfo: &files.ContentFileInfo{
+				Owner: content.FileInfo.Owner,
+				Group: content.FileInfo.Group,
+				Mode:  content.FileInfo.Mode,
+				MTime: content.FileInfo.ParsedMTime,
+			},
 		})
 	}
 
@@ -357,7 +380,8 @@ func create(ctx *context.Context, fpm config.NFPM, format string, artifacts []*a
 				Source:      filepath.ToSlash(src),
 				Destination: filepath.ToSlash(dst),
 				FileInfo: &files.ContentFileInfo{
-					Mode: 0o755,
+					Mode:  0o755,
+					MTime: fpm.ParsedMTime,
 				},
 			})
 		}
@@ -382,6 +406,7 @@ func create(ctx *context.Context, fpm config.NFPM, format string, artifacts []*a
 		Homepage:        fpm.Homepage,
 		License:         fpm.License,
 		Changelog:       fpm.Changelog,
+		MTime:           fpm.ParsedMTime,
 		Overridables: nfpm.Overridables{
 			Umask:      overridden.Umask,
 			Conflicts:  overridden.Conflicts,
@@ -404,6 +429,7 @@ func create(ctx *context.Context, fpm config.NFPM, format string, artifacts []*a
 				Scripts: nfpm.DebScripts{
 					Rules:     overridden.Deb.Scripts.Rules,
 					Templates: overridden.Deb.Scripts.Templates,
+					Config:    overridden.Deb.Scripts.Config,
 				},
 				Triggers: nfpm.DebTriggers{
 					Interest:        overridden.Deb.Triggers.Interest,
@@ -519,6 +545,11 @@ func create(ctx *context.Context, fpm config.NFPM, format string, artifacts []*a
 	if err := w.Close(); err != nil {
 		return fmt.Errorf("could not close package file: %w", err)
 	}
+	if !fpm.ParsedMTime.IsZero() {
+		if err := os.Chtimes(path, fpm.ParsedMTime, fpm.ParsedMTime); err != nil {
+			return fmt.Errorf("could not set package mtime: %w", err)
+		}
+	}
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Type:    artifact.LinuxPackage,
 		Name:    packageFilename,
