@@ -19,8 +19,11 @@ const (
 
 type Pipe struct{}
 
-func (Pipe) String() string                 { return "slack" }
-func (Pipe) Skip(ctx *context.Context) bool { return !ctx.Config.Announce.Slack.Enabled }
+func (Pipe) String() string { return "slack" }
+func (Pipe) Skip(ctx *context.Context) (bool, error) {
+	enable, err := tmpl.New(ctx).Bool(ctx.Config.Announce.Slack.Enabled)
+	return !enable, err
+}
 
 type Config struct {
 	Webhook string `env:"SLACK_WEBHOOK,notEmpty"`
