@@ -48,6 +48,7 @@ func TestRunPipeMissingInfo(t *testing.T) {
 }
 
 func TestRunPipe(t *testing.T) {
+	testlib.SkipIfWindows(t, "snap doesn't work in windows")
 	testlib.CheckPath(t, "snapcraft")
 	folder := t.TempDir()
 	dist := filepath.Join(folder, "dist")
@@ -98,7 +99,8 @@ func TestRunPipe(t *testing.T) {
 	require.Len(t, list, 9)
 }
 
-func TestBadTemolate(t *testing.T) {
+func TestBadTemplate(t *testing.T) {
+	testlib.SkipIfWindows(t, "snap doesn't work in windows")
 	testlib.CheckPath(t, "snapcraft")
 	folder := t.TempDir()
 	dist := filepath.Join(folder, "dist")
@@ -131,6 +133,7 @@ func TestBadTemolate(t *testing.T) {
 }
 
 func TestRunPipeInvalidNameTemplate(t *testing.T) {
+	testlib.SkipIfWindows(t, "snap doesn't work in windows")
 	testlib.CheckPath(t, "snapcraft")
 	folder := t.TempDir()
 	dist := filepath.Join(folder, "dist")
@@ -153,6 +156,7 @@ func TestRunPipeInvalidNameTemplate(t *testing.T) {
 }
 
 func TestRunPipeWithName(t *testing.T) {
+	testlib.SkipIfWindows(t, "snap doesn't work in windows")
 	testlib.CheckPath(t, "snapcraft")
 	folder := t.TempDir()
 	dist := filepath.Join(folder, "dist")
@@ -187,6 +191,7 @@ func TestRunPipeWithName(t *testing.T) {
 }
 
 func TestRunPipeMetadata(t *testing.T) {
+	testlib.SkipIfWindows(t, "snap doesn't work in windows")
 	testlib.CheckPath(t, "snapcraft")
 	folder := t.TempDir()
 	dist := filepath.Join(folder, "dist")
@@ -342,6 +347,7 @@ func TestNoSnapcraftInPath(t *testing.T) {
 }
 
 func TestRunNoArguments(t *testing.T) {
+	testlib.SkipIfWindows(t, "snap doesn't work in windows")
 	testlib.CheckPath(t, "snapcraft")
 	folder := t.TempDir()
 	dist := filepath.Join(folder, "dist")
@@ -376,6 +382,7 @@ func TestRunNoArguments(t *testing.T) {
 }
 
 func TestCompleter(t *testing.T) {
+	testlib.SkipIfWindows(t, "snap doesn't work in windows")
 	testlib.CheckPath(t, "snapcraft")
 	folder := t.TempDir()
 	dist := filepath.Join(folder, "dist")
@@ -413,6 +420,7 @@ func TestCompleter(t *testing.T) {
 }
 
 func TestCommand(t *testing.T) {
+	testlib.SkipIfWindows(t, "snap doesn't work in windows")
 	testlib.CheckPath(t, "snapcraft")
 	folder := t.TempDir()
 	dist := filepath.Join(folder, "dist")
@@ -448,6 +456,7 @@ func TestCommand(t *testing.T) {
 }
 
 func TestExtraFile(t *testing.T) {
+	testlib.SkipIfWindows(t, "snap doesn't work in windows")
 	testlib.CheckPath(t, "snapcraft")
 	folder := t.TempDir()
 	dist := filepath.Join(folder, "dist")
