@@ -11,12 +11,12 @@ import (
 	"time"
 
 	"github.com/goreleaser/nfpm/v2"
-	"github.com/goreleaser/nfpm/v2/files"
 	"github.com/invopop/jsonschema"
 )
 
 type Versioned struct {
 	Version int
+	Pro     bool
 }
 
 // Git configs.
@@ -542,10 +542,10 @@ type Build struct {
 	Main            string          `yaml:"main,omitempty" json:"main,omitempty"`
 	Binary          string          `yaml:"binary,omitempty" json:"binary,omitempty"`
 	Hooks           BuildHookConfig `yaml:"hooks,omitempty" json:"hooks,omitempty"`
-	Builder         string          `yaml:"builder,omitempty" json:"builder,omitempty" jsonschema:"enum=,enum=go,enum=rust,enum=zig"`
+	Builder         string          `yaml:"builder,omitempty" json:"builder,omitempty" jsonschema:"enum=,enum=go,enum=rust,enum=zig,enum=bun,enum=deno"`
 	ModTimestamp    string          `yaml:"mod_timestamp,omitempty" json:"mod_timestamp,omitempty"`
 	Skip            string          `yaml:"skip,omitempty" json:"skip,omitempty" jsonschema:"oneof_type=string;boolean"`
-	GoBinary        string          `yaml:"gobinary,omitempty" json:"gobinary,omitempty"` // Deprecated: use [ToolBinary].
+	GoBinary        string          `yaml:"gobinary,omitempty" json:"gobinary,omitempty"` // Deprecated: use [Build.Tool] instead.
 	Tool            string          `yaml:"tool,omitempty" json:"tool,omitempty"`
 	Command         string          `yaml:"command,omitempty" json:"command,omitempty"`
 	NoUniqueDistDir string          `yaml:"no_unique_dist_dir,omitempty" json:"no_unique_dist_dir,omitempty" jsonschema:"oneof_type=string;boolean"`
@@ -663,7 +663,10 @@ func (bh Hook) JSONSchema() *jsonschema.Schema {
 
 // FormatOverride is used to specify a custom format for a specific GOOS.
 type FormatOverride struct {
-	Goos   string `yaml:"goos,omitempty" json:"goos,omitempty"`
+	Goos    string      `yaml:"goos,omitempty" json:"goos,omitempty"`
+	Formats StringArray `yaml:"formats,omitempty" json:"formats,omitempty" jsonschema:"enum=tar,enum=tgz,enum=tar.gz,enum=zip,enum=gz,enum=tar.xz,enum=txz,enum=binary,enum=none,default=tar.gz"`
+
+	// Deprecated: use [Formats] instead.
 	Format string `yaml:"format,omitempty" json:"format,omitempty" jsonschema:"enum=tar,enum=tgz,enum=tar.gz,enum=zip,enum=gz,enum=tar.xz,enum=txz,enum=binary,enum=none,default=tar.gz"`
 }
 
@@ -748,13 +751,16 @@ type Archive struct {
 	Builds                    []string         `yaml:"builds,omitempty" json:"builds,omitempty"`
 	BuildsInfo                FileInfo         `yaml:"builds_info,omitempty" json:"builds_info,omitempty"`
 	NameTemplate              string           `yaml:"name_template,omitempty" json:"name_template,omitempty"`
-	Format                    string           `yaml:"format,omitempty" json:"format,omitempty" jsonschema:"enum=tar,enum=tgz,enum=tar.gz,enum=zip,enum=gz,enum=tar.xz,enum=txz,enum=binary,default=tar.gz"`
+	Formats                   StringArray      `yaml:"formats,omitempty" json:"formats,omitempty" jsonschema:"enum=tar,enum=tgz,enum=tar.gz,enum=zip,enum=gz,enum=tar.xz,enum=txz,enum=binary,default=tar.gz"`
 	FormatOverrides           []FormatOverride `yaml:"format_overrides,omitempty" json:"format_overrides,omitempty"`
 	WrapInDirectory           string           `yaml:"wrap_in_directory,omitempty" json:"wrap_in_directory,omitempty" jsonschema:"oneof_type=string;boolean"`
 	StripBinaryDirectory      bool             `yaml:"strip_binary_directory,omitempty" json:"strip_binary_directory,omitempty"`
 	Files                     []File           `yaml:"files,omitempty" json:"files,omitempty"`
 	Meta                      bool             `yaml:"meta,omitempty" json:"meta,omitempty"`
 	AllowDifferentBinaryCount bool             `yaml:"allow_different_binary_count,omitempty" json:"allow_different_binary_count,omitempty"`
+
+	// Deprecated: use [Formats] instead.
+	Format string `yaml:"format,omitempty" json:"format,omitempty" jsonschema:"enum=tar,enum=tgz,enum=tar.gz,enum=zip,enum=gz,enum=tar.xz,enum=txz,enum=binary,default=tar.gz"`
 }
 
 type ReleaseNotesMode string
@@ -823,7 +829,10 @@ type NFPM struct {
 	Bindir      string   `yaml:"bindir,omitempty" json:"bindir,omitempty"`
 	Libdirs     Libdirs  `yaml:"libdirs,omitempty" json:"libdirs,omitempty"`
 	Changelog   string   `yaml:"changelog,omitempty" json:"changelog,omitempty"`
+	MTime       string   `yaml:"mtime,omitempty" json:"mtime,omitempty" `
 	Meta        bool     `yaml:"meta,omitempty" json:"meta,omitempty"` // make package without binaries - only deps
+
+	ParsedMTime time.Time `yaml:"-" json:"-"`
 }
 
 type Libdirs struct {
@@ -867,6 +876,7 @@ type NFPMRPM struct {
 type NFPMDebScripts struct {
 	Rules     string `yaml:"rules,omitempty" json:"rules,omitempty"`
 	Templates string `yaml:"templates,omitempty" json:"templates,omitempty"`
+	Config    string `yaml:"config,omitempty" json:"config,omitempty"`
 }
 
 // NFPMDebTriggers contains triggers only available for deb packages.
@@ -968,26 +978,35 @@ func (ipk NFPMIPK) ToNFPAlts() []nfpm.IPKAlternative {
 
 // NFPMOverridables is used to specify per package format settings.
 type NFPMOverridables struct {
-	FileNameTemplate string         `yaml:"file_name_template,omitempty" json:"file_name_template,omitempty"`
-	PackageName      string         `yaml:"package_name,omitempty" json:"package_name,omitempty"`
-	Epoch            string         `yaml:"epoch,omitempty" json:"epoch,omitempty"`
-	Release          string         `yaml:"release,omitempty" json:"release,omitempty"`
-	Prerelease       string         `yaml:"prerelease,omitempty" json:"prerelease,omitempty"`
-	VersionMetadata  string         `yaml:"version_metadata,omitempty" json:"version_metadata,omitempty"`
-	Dependencies     []string       `yaml:"dependencies,omitempty" json:"dependencies,omitempty"`
-	Recommends       []string       `yaml:"recommends,omitempty" json:"recommends,omitempty"`
-	Suggests         []string       `yaml:"suggests,omitempty" json:"suggests,omitempty"`
-	Conflicts        []string       `yaml:"conflicts,omitempty" json:"conflicts,omitempty"`
-	Umask            fs.FileMode    `yaml:"umask,omitempty" json:"umask,omitempty" jsonschema:"oneof_type=string;integer"`
-	Replaces         []string       `yaml:"replaces,omitempty" json:"replaces,omitempty"`
-	Provides         []string       `yaml:"provides,omitempty" json:"provides,omitempty"`
-	Contents         files.Contents `yaml:"contents,omitempty" json:"contents,omitempty"`
-	Scripts          NFPMScripts    `yaml:"scripts,omitempty" json:"scripts,omitempty"`
-	RPM              NFPMRPM        `yaml:"rpm,omitempty" json:"rpm,omitempty"`
-	Deb              NFPMDeb        `yaml:"deb,omitempty" json:"deb,omitempty"`
-	APK              NFPMAPK        `yaml:"apk,omitempty" json:"apk,omitempty"`
-	ArchLinux        NFPMArchLinux  `yaml:"archlinux,omitempty" json:"archlinux,omitempty"`
-	IPK              NFPMIPK        `yaml:"ipk,omitempty" json:"ipk,omitempty"`
+	FileNameTemplate string        `yaml:"file_name_template,omitempty" json:"file_name_template,omitempty"`
+	PackageName      string        `yaml:"package_name,omitempty" json:"package_name,omitempty"`
+	Epoch            string        `yaml:"epoch,omitempty" json:"epoch,omitempty"`
+	Release          string        `yaml:"release,omitempty" json:"release,omitempty"`
+	Prerelease       string        `yaml:"prerelease,omitempty" json:"prerelease,omitempty"`
+	VersionMetadata  string        `yaml:"version_metadata,omitempty" json:"version_metadata,omitempty"`
+	Dependencies     []string      `yaml:"dependencies,omitempty" json:"dependencies,omitempty"`
+	Recommends       []string      `yaml:"recommends,omitempty" json:"recommends,omitempty"`
+	Suggests         []string      `yaml:"suggests,omitempty" json:"suggests,omitempty"`
+	Conflicts        []string      `yaml:"conflicts,omitempty" json:"conflicts,omitempty"`
+	Umask            fs.FileMode   `yaml:"umask,omitempty" json:"umask,omitempty" jsonschema:"oneof_type=string;integer"`
+	Replaces         []string      `yaml:"replaces,omitempty" json:"replaces,omitempty"`
+	Provides         []string      `yaml:"provides,omitempty" json:"provides,omitempty"`
+	Contents         []NFPMContent `yaml:"contents,omitempty" json:"contents,omitempty"`
+	Scripts          NFPMScripts   `yaml:"scripts,omitempty" json:"scripts,omitempty"`
+	RPM              NFPMRPM       `yaml:"rpm,omitempty" json:"rpm,omitempty"`
+	Deb              NFPMDeb       `yaml:"deb,omitempty" json:"deb,omitempty"`
+	APK              NFPMAPK       `yaml:"apk,omitempty" json:"apk,omitempty"`
+	ArchLinux        NFPMArchLinux `yaml:"archlinux,omitempty" json:"archlinux,omitempty"`
+	IPK              NFPMIPK       `yaml:"ipk,omitempty" json:"ipk,omitempty"`
+}
+
+type NFPMContent struct {
+	Source      string   `yaml:"src,omitempty" json:"src,omitempty"`
+	Destination string   `yaml:"dst" json:"dst"`
+	Type        string   `yaml:"type,omitempty" json:"type,omitempty" jsonschema:"enum=symlink,enum=ghost,enum=config,enum=config|noreplace,enum=dir,enum=tree,enum=,default="`
+	Packager    string   `yaml:"packager,omitempty" json:"packager,omitempty"`
+	FileInfo    FileInfo `yaml:"file_info,omitempty" json:"file_info,omitempty"`
+	Expand      bool     `yaml:"expand,omitempty" json:"expand,omitempty"`
 }
 
 // SBOM config.
@@ -1038,6 +1057,9 @@ type MacOSNotarize struct {
 type MacOSSign struct {
 	Certificate string `yaml:"certificate" json:"certificate"`
 	Password    string `yaml:"password" json:"password"`
+
+	// v2.6+
+	Entitlements string `yaml:"entitlements,omitempty" json:"entitlements,omitempty"`
 }
 
 // SnapcraftAppMetadata for the binaries that will be in the snap package.
@@ -1238,6 +1260,7 @@ type Upload struct {
 	CustomHeaders      map[string]string `yaml:"custom_headers,omitempty" json:"custom_headers,omitempty"`
 	ExtraFiles         []ExtraFile       `yaml:"extra_files,omitempty" json:"extra_files,omitempty"`
 	ExtraFilesOnly     bool              `yaml:"extra_files_only,omitempty" json:"extra_files_only,omitempty"`
+	Skip               string            `yaml:"skip,omitempty" json:"skip,omitempty" jsonschema:"oneof_type=string;boolean"`
 }
 
 // Publisher configuration.
@@ -1266,6 +1289,7 @@ type Source struct {
 // Project includes all project configuration.
 type Project struct {
 	Version         int              `yaml:"version,omitempty" json:"version,omitempty" jsonschema:"enum=2,default=2"`
+	Pro             bool             `yaml:"pro,omitempty" json:"pro,omitempty"`
 	ProjectName     string           `yaml:"project_name,omitempty" json:"project_name,omitempty"`
 	Env             []string         `yaml:"env,omitempty" json:"env,omitempty"`
 	Release         Release          `yaml:"release,omitempty" json:"release,omitempty"`
@@ -1353,7 +1377,7 @@ type Announce struct {
 }
 
 type Webhook struct {
-	Enabled             bool              `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	Enabled             string            `yaml:"enabled,omitempty" json:"enabled,omitempty" jsonschema:"oneof_type=string;boolean"`
 	SkipTLSVerify       bool              `yaml:"skip_tls_verify,omitempty" json:"skip_tls_verify,omitempty"`
 	MessageTemplate     string            `yaml:"message_template,omitempty" json:"message_template,omitempty"`
 	EndpointURL         string            `yaml:"endpoint_url,omitempty" json:"endpoint_url,omitempty"`
@@ -1363,18 +1387,18 @@ type Webhook struct {
 }
 
 type Twitter struct {
-	Enabled         bool   `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	Enabled         string `yaml:"enabled,omitempty" json:"enabled,omitempty" jsonschema:"oneof_type=string;boolean"`
 	MessageTemplate string `yaml:"message_template,omitempty" json:"message_template,omitempty"`
 }
 
 type Mastodon struct {
-	Enabled         bool   `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	Enabled         string `yaml:"enabled,omitempty" json:"enabled,omitempty" jsonschema:"oneof_type=string;boolean"`
 	MessageTemplate string `yaml:"message_template,omitempty" json:"message_template,omitempty"`
 	Server          string `yaml:"server" json:"server"`
 }
 
 type Reddit struct {
-	Enabled       bool   `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	Enabled       string `yaml:"enabled,omitempty" json:"enabled,omitempty" jsonschema:"oneof_type=string;boolean"`
 	ApplicationID string `yaml:"application_id,omitempty" json:"application_id,omitempty"`
 	Username      string `yaml:"username,omitempty" json:"username,omitempty"`
 	TitleTemplate string `yaml:"title_template,omitempty" json:"title_template,omitempty"`
@@ -1383,7 +1407,7 @@ type Reddit struct {
 }
 
 type Slack struct {
-	Enabled         bool              `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	Enabled         string            `yaml:"enabled,omitempty" json:"enabled,omitempty" jsonschema:"oneof_type=string;boolean"`
 	MessageTemplate string            `yaml:"message_template,omitempty" json:"message_template,omitempty"`
 	Channel         string            `yaml:"channel,omitempty" json:"channel,omitempty"`
 	Username        string            `yaml:"username,omitempty" json:"username,omitempty"`
@@ -1394,7 +1418,7 @@ type Slack struct {
 }
 
 type Discord struct {
-	Enabled         bool   `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	Enabled         string `yaml:"enabled,omitempty" json:"enabled,omitempty" jsonschema:"oneof_type=string;boolean"`
 	MessageTemplate string `yaml:"message_template,omitempty" json:"message_template,omitempty"`
 	Author          string `yaml:"author,omitempty" json:"author,omitempty"`
 	Color           string `yaml:"color,omitempty" json:"color,omitempty"`
@@ -1402,7 +1426,7 @@ type Discord struct {
 }
 
 type Teams struct {
-	Enabled         bool   `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	Enabled         string `yaml:"enabled,omitempty" json:"enabled,omitempty" jsonschema:"oneof_type=string;boolean"`
 	TitleTemplate   string `yaml:"title_template,omitempty" json:"title_template,omitempty"`
 	MessageTemplate string `yaml:"message_template,omitempty" json:"message_template,omitempty"`
 	Color           string `yaml:"color,omitempty" json:"color,omitempty"`
@@ -1410,7 +1434,7 @@ type Teams struct {
 }
 
 type Mattermost struct {
-	Enabled         bool   `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	Enabled         string `yaml:"enabled,omitempty" json:"enabled,omitempty" jsonschema:"oneof_type=string;boolean"`
 	MessageTemplate string `yaml:"message_template,omitempty" json:"message_template,omitempty"`
 	TitleTemplate   string `yaml:"title_template,omitempty" json:"title_template,omitempty"`
 	Color           string `yaml:"color,omitempty" json:"color,omitempty"`
@@ -1421,7 +1445,7 @@ type Mattermost struct {
 }
 
 type SMTP struct {
-	Enabled            bool     `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	Enabled            string   `yaml:"enabled,omitempty" json:"enabled,omitempty" jsonschema:"oneof_type=string;boolean"`
 	Host               string   `yaml:"host,omitempty" json:"host,omitempty"`
 	Port               int      `yaml:"port,omitempty" json:"port,omitempty"`
 	Username           string   `yaml:"username,omitempty" json:"username,omitempty"`
@@ -1433,19 +1457,19 @@ type SMTP struct {
 }
 
 type LinkedIn struct {
-	Enabled         bool   `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	Enabled         string `yaml:"enabled,omitempty" json:"enabled,omitempty" jsonschema:"oneof_type=string;boolean"`
 	MessageTemplate string `yaml:"message_template,omitempty" json:"message_template,omitempty"`
 }
 
 type Telegram struct {
-	Enabled         bool   `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	Enabled         string `yaml:"enabled,omitempty" json:"enabled,omitempty" jsonschema:"oneof_type=string;boolean"`
 	MessageTemplate string `yaml:"message_template,omitempty" json:"message_template,omitempty"`
 	ChatID          string `yaml:"chat_id,omitempty" json:"chat_id,omitempty" jsonschema:"oneof_type=string;integer"`
 	ParseMode       string `yaml:"parse_mode,omitempty" json:"parse_mode,omitempty" jsonschema:"enum=MarkdownV2,enum=HTML,default=MarkdownV2"`
 }
 
 type OpenCollective struct {
-	Enabled         bool   `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	Enabled         string `yaml:"enabled,omitempty" json:"enabled,omitempty" jsonschema:"oneof_type=string;boolean"`
 	Slug            string `yaml:"slug,omitempty" json:"slug,omitempty"`
 	TitleTemplate   string `yaml:"title_template,omitempty" json:"title_template,omitempty"`
 	MessageTemplate string `yaml:"message_template,omitempty" json:"message_template,omitempty"`
@@ -1453,7 +1477,7 @@ type OpenCollective struct {
 
 // Bluesky represents the data required to announce to the Bluesky social network
 type Bluesky struct {
-	Enabled         bool   `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	Enabled         string `yaml:"enabled,omitempty" json:"enabled,omitempty" jsonschema:"oneof_type=string;boolean"`
 	Username        string `yaml:"username,omitempty" json:"username,omitempty"`
 	MessageTemplate string `yaml:"message_template,omitempty" json:"message_template,omitempty"`
 }
