@@ -1,6 +1,7 @@
 package config
 
 import (
+	"errors"
 	"fmt"
 	"io"
 	"os"
@@ -16,9 +17,13 @@ type VersionError struct {
 	current int
 }
 
+// ErrProConfig happens if the configuration failed to load strictly, but
+// there's a 'pro: true' field in it, so we just allow anything.
+var ErrProConfig = errors.New("you are using a GoReleaser Pro configuration file with GoReleaser OSS")
+
 func (e VersionError) Error() string {
 	return fmt.Sprintf(
-		"only configurations files on %s are supported, yours is %s, please update your configuration",
+		"only %s configuration files are supported, yours is %s, please update your configuration",
 		logext.Keyword("version: 2"),
 		logext.Keyword(fmt.Sprintf("version: %d", e.current)),
 	)
@@ -55,5 +60,11 @@ func LoadReader(fd io.Reader) (config Project, err error) {
 	if err != nil && !validVersion {
 		return config, VersionError{versioned.Version}
 	}
+	if err != nil && versioned.Pro {
+		err2 := yaml.Unmarshal(data, &config)
+		if err2 == nil {
+			err = errors.Join(err, ErrProConfig)
+		}
+	}
 	return config, err
 }
